@@ -106,8 +106,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             languages = ['en_US', 'it_IT', 'es_MX', 'es_ES', 'de_DE', 'ja_JP'])
         self.assertEqual(
             mq.candidates('😺', match_limit=3),
-            [('😺', 'smiling cat face with open mouth [😺, So, people, cat, face, mouth, open, smile, uc6, grinning]', 10), ('😆', 'smiling face with open mouth and tightly-closed eyes [So, people, face, mouth, open, smile, uc6]', 7), ('😄', 'smiling face with open mouth and smiling eyes [So, people, face, mouth, open, smile, uc6]', 7)]
-        )
+            [('😺', 'smiling cat face with open mouth [😺, So, people, cat, face, mouth, open, smile, uc6, animal, grinning, smiling]', 12), ('😸', 'grinning cat face with smiling eyes [So, people, cat, face, smile, uc6, animal, grinning, smiling]', 9), ('😅', 'smiling face with open mouth and cold sweat [So, people, face, open, smile, uc6, grinning, mouth, smiling]', 9)])
 
     def test_candidates_japanese_full_width_low_line(self) -> None:
         # ＿ U+FF3F FULLWIDTH LOW LINE should not disturb the match
@@ -169,9 +168,9 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             ('😺', 'gatto che sorride'))
         self.assertEqual(
             mq.candidates('nerd glasses')[0][:2],
-            ('🤓', 'nerd face'))
+            ('🤓', 'nerd face [glasses]'))
         self.assertEqual(
-            mq.candidates('smiling face sun glasses')[0][:2],
+            mq.candidates('smiling face with sunglasses')[0][:2],
             ('😎', 'smiling face with sunglasses'))
 
     def test_candidates_skin_tones(self) -> None:
@@ -287,17 +286,17 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             ('👨\u200d👨\u200d👧\u200d👦', 'family: man, man, girl, boy'))
         self.assertEqual(
             mq.candidates('people')[0][:2],
-            ('🧑🏾\u200d🤝\u200d🧑🏼', 'people holding hands: medium-dark skin tone, medium-light skin tone “people holding hands medium dark skin tone medium light skin tone”'))
+            ('👯', 'woman with bunny ears “people with bunny ears partying”'))
 
     def test_candidates_birthday_cake(self) -> None:
         mq = itb_emoji.EmojiMatcher(
             languages = ['en_US', 'it_IT', 'es_MX', 'es_ES', 'de_DE', 'ja_JP'])
         self.assertEqual(
-            mq.candidates('bir')[0][:2],
+            mq.candidates('birthday')[0][:2],
             ('🎂', 'birthday cake'))
         self.assertEqual(
             mq.candidates('birth')[0][:2],
-            ('🎂', 'birthday cake'))
+            ('🍼', 'baby bottle [birth]'))
 
     @unittest.skipUnless(
         IMPORT_ENCHANT_SUCCESSFUL,
@@ -310,7 +309,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             languages = ['en_US', 'it_IT', 'es_MX', 'es_ES', 'de_DE', 'ja_JP'])
         self.assertEqual(
             mq.candidates('symbol')[0][:2],
-            ('🔣', 'input symbol for symbols {Symbol}'))
+            ('♻️', 'black universal recycling symbol {Symbol}'))
         self.assertEqual(
             mq.candidates('atomsymbol')[0][:2],
             ('⚛\ufe0f', 'atom symbol'))
@@ -332,16 +331,16 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             languages = ['en_US', 'it_IT', 'es_MX', 'es_ES', 'de_DE', 'ja_JP'])
         self.assertEqual(
             mq.candidates('animal')[0][:2],
-            ('🦍', 'gorilla [animal]'))
+            ('🐕', 'dog [animal]'))
         self.assertEqual(
             mq.candidates('dromedary animal')[0][:2],
-            ('🐪', 'dromedary camel'))
+            ('🐪', 'dromedary camel [animal]'))
         self.assertEqual(
             mq.candidates('camel')[0][:2],
             ('🐫', 'bactrian camel'))
         self.assertEqual(
             mq.candidates('nature')[0][:2],
-            ('🙈', 'see-no-evil monkey {nature}'))
+            ('🐌', 'snail {nature}'))
 
     def test_candidates_travel(self) -> None:
         mq = itb_emoji.EmojiMatcher(
@@ -351,7 +350,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             ('📷', 'camera'))
         self.assertEqual(
             mq.candidates('travel')[0][:2],
-            ('\U0001f9f3', 'luggage {travel}'))
+            ('🚂', 'steam locomotive {travel}'))
         self.assertEqual(
             mq.candidates('ferry')[0][:2],
             ('⛴\ufe0f', 'ferry'))
@@ -422,10 +421,10 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             ('‼\ufe0f', 'double exclamation mark {Punctuation} [punctuation]'))
         self.assertEqual(
             mq.candidates('final quote')[0][:2],
-            ('’', 'right single quotation mark {Final quote}'))
+            ('”', 'right double quotation mark {Final quote}'))
         self.assertEqual(
             mq.candidates('initial quote')[0][:2],
-            ('‘', 'left single quotation mark {Initial quote}'))
+            ('“', 'left double quotation mark {Initial quote}'))
         self.assertEqual(
             mq.candidates('modifier')[0][:2],
             ('🏻', 'emoji modifier fitzpatrick type-1-2 {Modifier}'))
@@ -457,7 +456,7 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             languages = ['fr_FR'])
         self.assertEqual(
             mq.candidates('🤔', match_limit = 3),
-            [('🤔', 'visage en pleine réflexion [🤔, réflexion, visage, visage en pleine réflexion]', 4), ('🤐', 'visage avec bouche fermeture éclair [visage]', 1), ('🤗', 'visage qui fait un câlin [visage]', 1)])
+            [('🤔', 'visage en pleine réflexion [🤔, émoticône, hum, méditer, penser, réfléchir, réflexion, visage, visage en pleine réflexion]', 9), ('🤐', 'visage avec bouche fermeture éclair [émoticône, visage]', 2), ('🤗', 'visage qui fait un câlin [émoticône, visage]', 2)])
 
     def test_candidates_code_point_input(self) -> None:
         mq = itb_emoji.EmojiMatcher(
@@ -572,11 +571,14 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             mq.candidates('かたつむり＿')[0][:2],
             ('🐌', 'かたつむり'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ')))
+            mq.candidates('カタツムリ')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ_')))
+            mq.candidates('カタツムリ_')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ＿')))
+            mq.candidates('カタツムリ＿')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
             mq.candidates('ネコ')[0][:2],
             ('🐈', 'ネコ'))
@@ -612,11 +614,14 @@ class EmojiCandidatesTestCase(unittest.TestCase):
             mq.candidates('かたつむり＿')[0][:2],
             ('🐌', 'かたつむり'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ')))
+            mq.candidates('カタツムリ')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ_')))
+            mq.candidates('カタツムリ_')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
-            0, len(mq.candidates('カタツムリ＿')))
+            mq.candidates('カタツムリ＿')[0][:2],
+            ('🐌', 'かたつむり [カタツムリ]'))
         self.assertEqual(
             mq.candidates('ネコ')[0][:2],
             ('🐈', 'ネコ'))
